@@ -1,12 +1,7 @@
+from importlib import resources
 import os
 from urllib.parse import quote_plus
 
-try:
-    from importlib import resources
-except ImportError:
-    # FIXME: remove after dropping support for Python < 3.7
-    import importlib_resources as resources
-
 from lxml.etree import fromstring
 
 from . import data
